@@ -1,8 +1,11 @@
 import copy
+import random
 
 from ..config.parser import ModuleClass
 from ..core.component import Component as BaseComponent
 from ..utils.traits import Jsonable
+from ..utils.identifiers import encode_experiment_id, generate_component_id
+from ..utils.utils import generate_seed
 
 
 def recover_class(element):
@@ -25,9 +28,10 @@ def recover_class(element):
 
 
 class Schedule(Jsonable):
-    def __init__(self, elements=None):
+    def __init__(self, elements=None, seed=None):
         self._elements = elements or []
         self._result = []
+        self._seed = seed
 
     def add(
         self, execution_type, component, components, resources, args=None, kwargs=None,
@@ -35,14 +39,62 @@ class Schedule(Jsonable):
         self._elements.append(
             [execution_type, component, components, resources, args, kwargs]
         )
+        return self
+
+    def set_seed(self, seed=None):
+        if not isinstance(seed, int):
+            raise ValueError("Seed must be integer")
+
+        if seed == self._seed:
+            return self
+
+        experiment_id = encode_experiment_id(seed, or_fail=False)
+        seed_random_state = random.Random(seed)
+
+        for i in range(len(self._elements)):
+            flags = self._elements[i][1]["flags"]
+            flags["GLOBAL_SEED"] = seed
+            flags["EXPERIMENT_ID"] = experiment_id
+            flags["SEED"] = generate_seed(random_state=seed_random_state)
+            flags["COMPONENT_ID"] = generate_component_id()[0]
+
+        return self
 
     @property
     def elements(self):
         return copy.deepcopy(self._elements)
 
+    @property
+    def components(self):
+        return [
+            component["flags"]["COMPONENT_ID"] for _, component, *__ in self._elements
+        ]
+
     def filter(self, callback=None):
+        """Filter the schedule elements in-place
+
+        # Arguments
+        callback: Callable that represents filter condition (returns True for values to keep)
+           It must accept 3 arguments, the index of the element in the schedule, the component
+           identifier and the schedule element
+
+        # Examples
+        ```python
+        e.filter(lambda i, component, _: component == '$COMPONENT_ID')
+        ```
+        """
         self._elements = [
-            args[1] for args in enumerate(self._elements) if callback(*args)
+            element
+            for i, element in enumerate(self._elements)
+            if callback(i, element[1]["flags"]["COMPONENT_ID"], element)
+        ]
+
+        return self
+
+    def transform(self, callback):
+        self._elements = [
+            callback(i, element[1]["flags"]["COMPONENT_ID"], element)
+            for i, element in enumerate(self._elements)
         ]
 
         return self
@@ -63,6 +115,8 @@ class Schedule(Jsonable):
 
         self._result[index] = result
 
+        return self
+
     def serialize(self):
         serialized = []
         for (
