@@ -1,14 +1,13 @@
 import copy
 import random
 
-from ..execution.identifiers import encode_experiment_id, generate_component_id
+from ..utils.identifiers import encode_experiment_id, generate_component_id
 from ..utils.dicts import update_dict
 from ..utils.utils import generate_seed
 
 
 def parse_experiment(experiment, seed=None):
     seed_random_state = random.Random(seed)
-    uid_random_state = random.Random(seed)
     experiment_id = encode_experiment_id(seed, or_fail=False)
 
     # repeat behaviour
@@ -47,9 +46,7 @@ def parse_experiment(experiment, seed=None):
             node.flags["GLOBAL_SEED"] = seed
             node.flags["EXPERIMENT_ID"] = experiment_id
             node.flags["SEED"] = generate_seed(random_state=seed_random_state)
-            node.flags["COMPONENT_ID"] = generate_component_id(
-                random_state=uid_random_state
-            )[0]
+            node.flags["COMPONENT_ID"] = generate_component_id()[0]
             node.flags.update(repeat)
 
             yield node, components, resources
